@@ -103,7 +103,8 @@ SERVICES = {
 
 
 def initialize(host, admin_token, admin_email, admin_password,
-               region='regionOne', ssl=None, public=None, user='root'):
+               region='regionOne', ssl=None, public=None, user='root',
+               timeout=600, poll_interval=10):
     """Perform post-heat initialization of Keystone.
 
     :param host: ip/hostname of node where Keystone is running
@@ -115,11 +116,13 @@ def initialize(host, admin_token, admin_email, admin_password,
     :param public: ip/hostname to use as the public endpoint, if the default
         is not suitable
     :param user: user to use to connect to the node where Keystone is running
+    :param timeout: Total seconds to wait for keystone to be running
+    :param poll_interval: Seconds to wait between keystone poll attempts
     """
 
     keystone = _create_admin_client(host, admin_token)
 
-    _create_roles(keystone)
+    _create_roles(keystone, timeout, poll_interval)
     _create_tenants(keystone)
     _create_admin_user(keystone, admin_email, admin_password)
     _create_keystone_endpoint(keystone, host, region, ssl, public)
@@ -372,19 +375,23 @@ def _create_admin_client(host, admin_token):
     return ksclient.Client(endpoint=admin_url, token=admin_token)
 
 
-def _create_roles(keystone):
+def _create_roles(keystone, timeout=600, poll_interval=10):
     """Create initial roles in Keystone.
 
     :param keystone: keystone v2 client
+    :param timeout: total seconds to wait for keystone
+    :param poll_interval: seconds to wait between keystone checks
     """
-    for count in range(60):
+    wait_cycles = int(timeout / poll_interval)
+    for count in range(wait_cycles):
         try:
             LOG.debug('Creating admin role, try %d.' % count)
             _create_role(keystone, 'admin')
             break
         except (exceptions.ConnectionRefused, exceptions.ServiceUnavailable):
-            LOG.debug('Unable to create, sleeping for 10 seconds.')
-            time.sleep(10)
+            LOG.debug('Unable to create, sleeping for %d seconds.'
+                      % poll_interval)
+            time.sleep(poll_interval)
     _create_role(keystone, 'Member')
 
 
